from ..broker import Broker


class DevicePasswordLogBroker(Broker):
    controller = "device_password_logs"

    def index(self, **kwargs):
        """Lists the available device password logs. Any of the inputs listed may be be used to narrow the list; other inputs will be ignored. Of the various ways to query lists, using this method is most efficient.

            **Inputs**

            |  ``api version min:`` 2.4
            |  ``api version max:`` 2.4
            |  ``required:`` False
            |  ``default:`` None

             :param DeviceID: The internal NetMRI identifier for the device from which device password log table information was collected.
             :type DeviceID: Integer

            |  ``api version min:`` 2.5
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param DeviceID: The internal NetMRI identifier for the device from which device password log table information was collected.
             :type DeviceID: Array of Integer

            |  ``api version min:`` 2.4
            |  ``api version max:`` 2.4
            |  ``required:`` False
            |  ``default:`` None

             :param DevicePwLogID: The internal NetMRI identifier for the device password log.
             :type DevicePwLogID: Integer

            |  ``api version min:`` 2.5
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param DevicePwLogID: The internal NetMRI identifier for the device password log.
             :type DevicePwLogID: Array of Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param DeviceGroupID: The internal NetMRI identifier of the device groups to which to limit the results.
             :type DeviceGroupID: Array of Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param timestamp: The data returned will represent the device password logs as of this date and time. If omitted, the result will indicate the most recently collected data.
             :type timestamp: DateTime

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param methods: A list of device password log methods. The listed methods will be called on each device password log returned and included in the output. Available methods are: device.
             :type methods: Array of String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param include: A list of associated object types to include in the output. The listed associations will be returned as outputs named according to the association name (see outputs below). Available includes are: device.
             :type include: Array of String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` 0

             :param start: The record number to return in the selected page of data. It will always appear, although it may not be the first record. See the :limit for more information.
             :type start: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` 1000

             :param limit: The size of the page of data, that is, the maximum number of records returned. The limit size will be used to break the data up into pages and the first page with the start record will be returned. So if you have 100 records and use a :limit of 10 and a :start of 10, you will get records 10-19. The maximum limit is 10000.
             :type limit: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` DevicePwLogID

             :param sort: The data field(s) to use for sorting the output. Default is DevicePwLogID. Valid values are DevicePwLogID, DataSourceID, DeviceID, DevicePwLogTimestamp, DevicePwLogProtocol, DevicePwLogSNMPAuthProto, DevicePwLogSNMPPrivProto, DevicePwLogStatus, DevicePwLogUsernameSecure, DevicePwLogPasswordSecure, DevicePwLogEnablePasswordSecure, DevicePwLogSNMPAuthPWSecure, DevicePwLogSNMPPrivPWSecure, SecureVersion.
             :type sort: Array of String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` asc

             :param dir: The direction(s) in which to sort the data. Default is 'asc'. Valid values are 'asc' and 'desc'.
             :type dir: Array of String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param select: The list of attributes to return for each DevicePasswordLog. Valid values are DevicePwLogID, DataSourceID, DeviceID, DevicePwLogTimestamp, DevicePwLogProtocol, DevicePwLogSNMPAuthProto, DevicePwLogSNMPPrivProto, DevicePwLogStatus, DevicePwLogUsernameSecure, DevicePwLogPasswordSecure, DevicePwLogEnablePasswordSecure, DevicePwLogSNMPAuthPWSecure, DevicePwLogSNMPPrivPWSecure, SecureVersion. If empty or omitted, all attributes will be returned.
             :type select: Array

            |  ``api version min:`` 2.8
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param goto_field: The field name for NIOS GOTO that is used for locating a row position of records.
             :type goto_field: String

            |  ``api version min:`` 2.8
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param goto_value: The value of goto_field for NIOS GOTO that is used for locating a row position of records.
             :type goto_value: String

            **Outputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :return device_password_logs: An array of the DevicePasswordLog objects that match the specified input criteria.
             :rtype device_password_logs: Array of DevicePasswordLog

            """

        return self.api_list_request(self._get_method_fullname("index"), kwargs)

    def show(self, **kwargs):
        """Shows the details for the specified device password log.

            **Inputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` True
            |  ``default:`` None

             :param DevicePwLogID: The internal NetMRI identifier for the device password log.
             :type DevicePwLogID: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param methods: A list of device password log methods. The listed methods will be called on each device password log returned and included in the output. Available methods are: device.
             :type methods: Array of String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param include: A list of associated object types to include in the output. The listed associations will be returned as outputs named according to the association name (see outputs below). Available includes are: device.
             :type include: Array of String

            **Outputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :return device_password_log: The device password log identified by the specified DevicePwLogID.
             :rtype device_password_log: DevicePasswordLog

            """

        return self.api_request(self._get_method_fullname("show"), kwargs)

    def search(self, **kwargs):
        """Lists the available device password logs matching the input criteria. This method provides a more flexible search interface than the index method, but searching using this method is more demanding on the system and will not perform to the same level as the index method. The input fields listed below will be used as in the index method, to filter the result, along with the optional query string and XML filter described below.

            **Inputs**

            |  ``api version min:`` 2.4
            |  ``api version max:`` 2.4
            |  ``required:`` False
            |  ``default:`` None

             :param DataSourceID: The internal NetMRI identifier for the collector NetMRI that collected this data record.
             :type DataSourceID: Integer

            |  ``api version min:`` 2.5
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param DataSourceID: The internal NetMRI identifier for the collector NetMRI that collected this data record.
             :type DataSourceID: Array of Integer

            |  ``api version min:`` 2.4
            |  ``api version max:`` 2.4
            |  ``required:`` False
            |  ``default:`` None

             :param DeviceID: The internal NetMRI identifier for the device from which device password log table information was collected.
             :type DeviceID: Integer

            |  ``api version min:`` 2.5
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param DeviceID: The internal NetMRI identifier for the device from which device password log table information was collected.
             :type DeviceID: Array of Integer

            |  ``api version min:`` 2.4
            |  ``api version max:`` 2.4
            |  ``required:`` False
            |  ``default:`` None

             :param DevicePwLogEnablePasswordSecure: The password is enabled for device password log.
             :type DevicePwLogEnablePasswordSecure: String

            |  ``api version min:`` 2.5
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param DevicePwLogEnablePasswordSecure: The password is enabled for device password log.
             :type DevicePwLogEnablePasswordSecure: Array of String

            |  ``api version min:`` 2.4
            |  ``api version max:`` 2.4
            |  ``required:`` False
            |  ``default:`` None

             :param DevicePwLogID: The internal NetMRI identifier for the device password log.
             :type DevicePwLogID: Integer

            |  ``api version min:`` 2.5
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param DevicePwLogID: The internal NetMRI identifier for the device password log.
             :type DevicePwLogID: Array of Integer

            |  ``api version min:`` 2.4
            |  ``api version max:`` 2.4
            |  ``required:`` False
            |  ``default:`` None

             :param DevicePwLogPasswordSecure: The password of the device password log.
             :type DevicePwLogPasswordSecure: String

            |  ``api version min:`` 2.5
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param DevicePwLogPasswordSecure: The password of the device password log.
             :type DevicePwLogPasswordSecure: Array of String

            |  ``api version min:`` 2.4
            |  ``api version max:`` 2.4
            |  ``required:`` False
            |  ``default:`` None

             :param DevicePwLogProtocol: The protocol of the device password log.
             :type DevicePwLogProtocol: String

            |  ``api version min:`` 2.5
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param DevicePwLogProtocol: The protocol of the device password log.
             :type DevicePwLogProtocol: Array of String

            |  ``api version min:`` 2.4
            |  ``api version max:`` 2.4
            |  ``required:`` False
            |  ``default:`` None

             :param DevicePwLogSNMPAuthPWSecure: The SNMP password is authenticated for the device password log.
             :type DevicePwLogSNMPAuthPWSecure: String

            |  ``api version min:`` 2.5
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param DevicePwLogSNMPAuthPWSecure: The SNMP password is authenticated for the device password log.
             :type DevicePwLogSNMPAuthPWSecure: Array of String

            |  ``api version min:`` 2.4
            |  ``api version max:`` 2.4
            |  ``required:`` False
            |  ``default:`` None

             :param DevicePwLogSNMPAuthProto: The SNMP password is authenticated for the device password log.
             :type DevicePwLogSNMPAuthProto: String

            |  ``api version min:`` 2.5
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param DevicePwLogSNMPAuthProto: The SNMP password is authenticated for the device password log.
             :type DevicePwLogSNMPAuthProto: Array of String

            |  ``api version min:`` 2.4
            |  ``api version max:`` 2.4
            |  ``required:`` False
            |  ``default:`` None

             :param DevicePwLogSNMPPrivPWSecure: The SNMP private password of the device password log.
             :type DevicePwLogSNMPPrivPWSecure: String

            |  ``api version min:`` 2.5
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param DevicePwLogSNMPPrivPWSecure: The SNMP private password of the device password log.
             :type DevicePwLogSNMPPrivPWSecure: Array of String

            |  ``api version min:`` 2.4
            |  ``api version max:`` 2.4
            |  ``required:`` False
            |  ``default:`` None

             :param DevicePwLogSNMPPrivProto: The SNMP private password protocol of the device password log.
             :type DevicePwLogSNMPPrivProto: String

            |  ``api version min:`` 2.5
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param DevicePwLogSNMPPrivProto: The SNMP private password protocol of the device password log.
             :type DevicePwLogSNMPPrivProto: Array of String

            |  ``api version min:`` 2.4
            |  ``api version max:`` 2.4
            |  ``required:`` False
            |  ``default:`` None

             :param DevicePwLogStatus: The status of the device password log.
             :type DevicePwLogStatus: String

            |  ``api version min:`` 2.5
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param DevicePwLogStatus: The status of the device password log.
             :type DevicePwLogStatus: Array of String

            |  ``api version min:`` 2.4
            |  ``api version max:`` 2.4
            |  ``required:`` False
            |  ``default:`` None

             :param DevicePwLogTimestamp: The date and time this record was collected or calculated.
             :type DevicePwLogTimestamp: DateTime

            |  ``api version min:`` 2.5
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param DevicePwLogTimestamp: The date and time this record was collected or calculated.
             :type DevicePwLogTimestamp: Array of DateTime

            |  ``api version min:`` 2.4
            |  ``api version max:`` 2.4
            |  ``required:`` False
            |  ``default:`` None

             :param DevicePwLogUsernameSecure: The username of the device password log.
             :type DevicePwLogUsernameSecure: String

            |  ``api version min:`` 2.5
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param DevicePwLogUsernameSecure: The username of the device password log.
             :type DevicePwLogUsernameSecure: Array of String

            |  ``api version min:`` 2.4
            |  ``api version max:`` 2.4
            |  ``required:`` False
            |  ``default:`` None

             :param SecureVersion: The encryption version of the username and passwords.
             :type SecureVersion: Integer

            |  ``api version min:`` 2.5
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param SecureVersion: The encryption version of the username and passwords.
             :type SecureVersion: Array of Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param DeviceGroupID: The internal NetMRI identifier of the device groups to which to limit the results.
             :type DeviceGroupID: Array of Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param timestamp: The data returned will represent the device password logs as of this date and time. If omitted, the result will indicate the most recently collected data.
             :type timestamp: DateTime

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param methods: A list of device password log methods. The listed methods will be called on each device password log returned and included in the output. Available methods are: device.
             :type methods: Array of String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param include: A list of associated object types to include in the output. The listed associations will be returned as outputs named according to the association name (see outputs below). Available includes are: device.
             :type include: Array of String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` 0

             :param start: The record number to return in the selected page of data. It will always appear, although it may not be the first record. See the :limit for more information.
             :type start: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` 1000

             :param limit: The size of the page of data, that is, the maximum number of records returned. The limit size will be used to break the data up into pages and the first page with the start record will be returned. So if you have 100 records and use a :limit of 10 and a :start of 10, you will get records 10-19. The maximum limit is 10000.
             :type limit: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` DevicePwLogID

             :param sort: The data field(s) to use for sorting the output. Default is DevicePwLogID. Valid values are DevicePwLogID, DataSourceID, DeviceID, DevicePwLogTimestamp, DevicePwLogProtocol, DevicePwLogSNMPAuthProto, DevicePwLogSNMPPrivProto, DevicePwLogStatus, DevicePwLogUsernameSecure, DevicePwLogPasswordSecure, DevicePwLogEnablePasswordSecure, DevicePwLogSNMPAuthPWSecure, DevicePwLogSNMPPrivPWSecure, SecureVersion.
             :type sort: Array of String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` asc

             :param dir: The direction(s) in which to sort the data. Default is 'asc'. Valid values are 'asc' and 'desc'.
             :type dir: Array of String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param select: The list of attributes to return for each DevicePasswordLog. Valid values are DevicePwLogID, DataSourceID, DeviceID, DevicePwLogTimestamp, DevicePwLogProtocol, DevicePwLogSNMPAuthProto, DevicePwLogSNMPPrivProto, DevicePwLogStatus, DevicePwLogUsernameSecure, DevicePwLogPasswordSecure, DevicePwLogEnablePasswordSecure, DevicePwLogSNMPAuthPWSecure, DevicePwLogSNMPPrivPWSecure, SecureVersion. If empty or omitted, all attributes will be returned.
             :type select: Array

            |  ``api version min:`` 2.8
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param goto_field: The field name for NIOS GOTO that is used for locating a row position of records.
             :type goto_field: String

            |  ``api version min:`` 2.8
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param goto_value: The value of goto_field for NIOS GOTO that is used for locating a row position of records.
             :type goto_value: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param query: This value will be matched against device password logs, looking to see if one or more of the listed attributes contain the passed value. You may also surround the value with '/' and '/' to perform a regular expression search rather than a containment operation. Any record that matches will be returned. The attributes searched are: DataSourceID, DeviceID, DevicePwLogEnablePasswordSecure, DevicePwLogID, DevicePwLogPasswordSecure, DevicePwLogProtocol, DevicePwLogSNMPAuthPWSecure, DevicePwLogSNMPAuthProto, DevicePwLogSNMPPrivPWSecure, DevicePwLogSNMPPrivProto, DevicePwLogStatus, DevicePwLogTimestamp, DevicePwLogUsernameSecure, SecureVersion.
             :type query: String

            |  ``api version min:`` 2.3
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param xml_filter: A SetFilter XML structure to further refine the search. The SetFilter will be applied AFTER any search query or field values, but before any limit options. The limit and pagination will be enforced after the filter. Remind that this kind of filter may be costly and inefficient if not associated with a database filtering.
             :type xml_filter: String

            **Outputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :return device_password_logs: An array of the DevicePasswordLog objects that match the specified input criteria.
             :rtype device_password_logs: Array of DevicePasswordLog

            """

        return self.api_list_request(self._get_method_fullname("search"), kwargs)

    def find(self, **kwargs):
        """Lists the available device password logs matching the input specification. This provides the most flexible search specification of all the query mechanisms, enabling searching using comparison operations other than equality. However, it is more complex to use and will not perform as efficiently as the index or search methods. In the input descriptions below, 'field names' refers to the following fields: DataSourceID, DeviceID, DevicePwLogEnablePasswordSecure, DevicePwLogID, DevicePwLogPasswordSecure, DevicePwLogProtocol, DevicePwLogSNMPAuthPWSecure, DevicePwLogSNMPAuthProto, DevicePwLogSNMPPrivPWSecure, DevicePwLogSNMPPrivProto, DevicePwLogStatus, DevicePwLogTimestamp, DevicePwLogUsernameSecure, SecureVersion.

            **Inputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_DataSourceID: The operator to apply to the field DataSourceID. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. DataSourceID: The internal NetMRI identifier for the collector NetMRI that collected this data record. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_DataSourceID: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_DataSourceID: If op_DataSourceID is specified, the field named in this input will be compared to the value in DataSourceID using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_DataSourceID must be specified if op_DataSourceID is specified.
             :type val_f_DataSourceID: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_DataSourceID: If op_DataSourceID is specified, this value will be compared to the value in DataSourceID using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_DataSourceID must be specified if op_DataSourceID is specified.
             :type val_c_DataSourceID: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_DeviceID: The operator to apply to the field DeviceID. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. DeviceID: The internal NetMRI identifier for the device from which device password log table information was collected. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_DeviceID: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_DeviceID: If op_DeviceID is specified, the field named in this input will be compared to the value in DeviceID using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_DeviceID must be specified if op_DeviceID is specified.
             :type val_f_DeviceID: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_DeviceID: If op_DeviceID is specified, this value will be compared to the value in DeviceID using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_DeviceID must be specified if op_DeviceID is specified.
             :type val_c_DeviceID: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_DevicePwLogEnablePasswordSecure: The operator to apply to the field DevicePwLogEnablePasswordSecure. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. DevicePwLogEnablePasswordSecure: The password is enabled for device password log. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_DevicePwLogEnablePasswordSecure: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_DevicePwLogEnablePasswordSecure: If op_DevicePwLogEnablePasswordSecure is specified, the field named in this input will be compared to the value in DevicePwLogEnablePasswordSecure using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_DevicePwLogEnablePasswordSecure must be specified if op_DevicePwLogEnablePasswordSecure is specified.
             :type val_f_DevicePwLogEnablePasswordSecure: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_DevicePwLogEnablePasswordSecure: If op_DevicePwLogEnablePasswordSecure is specified, this value will be compared to the value in DevicePwLogEnablePasswordSecure using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_DevicePwLogEnablePasswordSecure must be specified if op_DevicePwLogEnablePasswordSecure is specified.
             :type val_c_DevicePwLogEnablePasswordSecure: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_DevicePwLogID: The operator to apply to the field DevicePwLogID. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. DevicePwLogID: The internal NetMRI identifier for the device password log. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_DevicePwLogID: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_DevicePwLogID: If op_DevicePwLogID is specified, the field named in this input will be compared to the value in DevicePwLogID using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_DevicePwLogID must be specified if op_DevicePwLogID is specified.
             :type val_f_DevicePwLogID: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_DevicePwLogID: If op_DevicePwLogID is specified, this value will be compared to the value in DevicePwLogID using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_DevicePwLogID must be specified if op_DevicePwLogID is specified.
             :type val_c_DevicePwLogID: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_DevicePwLogPasswordSecure: The operator to apply to the field DevicePwLogPasswordSecure. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. DevicePwLogPasswordSecure: The password of the device password log. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_DevicePwLogPasswordSecure: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_DevicePwLogPasswordSecure: If op_DevicePwLogPasswordSecure is specified, the field named in this input will be compared to the value in DevicePwLogPasswordSecure using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_DevicePwLogPasswordSecure must be specified if op_DevicePwLogPasswordSecure is specified.
             :type val_f_DevicePwLogPasswordSecure: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_DevicePwLogPasswordSecure: If op_DevicePwLogPasswordSecure is specified, this value will be compared to the value in DevicePwLogPasswordSecure using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_DevicePwLogPasswordSecure must be specified if op_DevicePwLogPasswordSecure is specified.
             :type val_c_DevicePwLogPasswordSecure: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_DevicePwLogProtocol: The operator to apply to the field DevicePwLogProtocol. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. DevicePwLogProtocol: The protocol of the device password log. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_DevicePwLogProtocol: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_DevicePwLogProtocol: If op_DevicePwLogProtocol is specified, the field named in this input will be compared to the value in DevicePwLogProtocol using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_DevicePwLogProtocol must be specified if op_DevicePwLogProtocol is specified.
             :type val_f_DevicePwLogProtocol: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_DevicePwLogProtocol: If op_DevicePwLogProtocol is specified, this value will be compared to the value in DevicePwLogProtocol using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_DevicePwLogProtocol must be specified if op_DevicePwLogProtocol is specified.
             :type val_c_DevicePwLogProtocol: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_DevicePwLogSNMPAuthPWSecure: The operator to apply to the field DevicePwLogSNMPAuthPWSecure. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. DevicePwLogSNMPAuthPWSecure: The SNMP password is authenticated for the device password log. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_DevicePwLogSNMPAuthPWSecure: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_DevicePwLogSNMPAuthPWSecure: If op_DevicePwLogSNMPAuthPWSecure is specified, the field named in this input will be compared to the value in DevicePwLogSNMPAuthPWSecure using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_DevicePwLogSNMPAuthPWSecure must be specified if op_DevicePwLogSNMPAuthPWSecure is specified.
             :type val_f_DevicePwLogSNMPAuthPWSecure: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_DevicePwLogSNMPAuthPWSecure: If op_DevicePwLogSNMPAuthPWSecure is specified, this value will be compared to the value in DevicePwLogSNMPAuthPWSecure using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_DevicePwLogSNMPAuthPWSecure must be specified if op_DevicePwLogSNMPAuthPWSecure is specified.
             :type val_c_DevicePwLogSNMPAuthPWSecure: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_DevicePwLogSNMPAuthProto: The operator to apply to the field DevicePwLogSNMPAuthProto. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. DevicePwLogSNMPAuthProto: The SNMP password is authenticated for the device password log. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_DevicePwLogSNMPAuthProto: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_DevicePwLogSNMPAuthProto: If op_DevicePwLogSNMPAuthProto is specified, the field named in this input will be compared to the value in DevicePwLogSNMPAuthProto using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_DevicePwLogSNMPAuthProto must be specified if op_DevicePwLogSNMPAuthProto is specified.
             :type val_f_DevicePwLogSNMPAuthProto: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_DevicePwLogSNMPAuthProto: If op_DevicePwLogSNMPAuthProto is specified, this value will be compared to the value in DevicePwLogSNMPAuthProto using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_DevicePwLogSNMPAuthProto must be specified if op_DevicePwLogSNMPAuthProto is specified.
             :type val_c_DevicePwLogSNMPAuthProto: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_DevicePwLogSNMPPrivPWSecure: The operator to apply to the field DevicePwLogSNMPPrivPWSecure. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. DevicePwLogSNMPPrivPWSecure: The SNMP private password of the device password log. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_DevicePwLogSNMPPrivPWSecure: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_DevicePwLogSNMPPrivPWSecure: If op_DevicePwLogSNMPPrivPWSecure is specified, the field named in this input will be compared to the value in DevicePwLogSNMPPrivPWSecure using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_DevicePwLogSNMPPrivPWSecure must be specified if op_DevicePwLogSNMPPrivPWSecure is specified.
             :type val_f_DevicePwLogSNMPPrivPWSecure: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_DevicePwLogSNMPPrivPWSecure: If op_DevicePwLogSNMPPrivPWSecure is specified, this value will be compared to the value in DevicePwLogSNMPPrivPWSecure using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_DevicePwLogSNMPPrivPWSecure must be specified if op_DevicePwLogSNMPPrivPWSecure is specified.
             :type val_c_DevicePwLogSNMPPrivPWSecure: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_DevicePwLogSNMPPrivProto: The operator to apply to the field DevicePwLogSNMPPrivProto. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. DevicePwLogSNMPPrivProto: The SNMP private password protocol of the device password log. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_DevicePwLogSNMPPrivProto: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_DevicePwLogSNMPPrivProto: If op_DevicePwLogSNMPPrivProto is specified, the field named in this input will be compared to the value in DevicePwLogSNMPPrivProto using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_DevicePwLogSNMPPrivProto must be specified if op_DevicePwLogSNMPPrivProto is specified.
             :type val_f_DevicePwLogSNMPPrivProto: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_DevicePwLogSNMPPrivProto: If op_DevicePwLogSNMPPrivProto is specified, this value will be compared to the value in DevicePwLogSNMPPrivProto using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_DevicePwLogSNMPPrivProto must be specified if op_DevicePwLogSNMPPrivProto is specified.
             :type val_c_DevicePwLogSNMPPrivProto: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_DevicePwLogStatus: The operator to apply to the field DevicePwLogStatus. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. DevicePwLogStatus: The status of the device password log. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_DevicePwLogStatus: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_DevicePwLogStatus: If op_DevicePwLogStatus is specified, the field named in this input will be compared to the value in DevicePwLogStatus using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_DevicePwLogStatus must be specified if op_DevicePwLogStatus is specified.
             :type val_f_DevicePwLogStatus: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_DevicePwLogStatus: If op_DevicePwLogStatus is specified, this value will be compared to the value in DevicePwLogStatus using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_DevicePwLogStatus must be specified if op_DevicePwLogStatus is specified.
             :type val_c_DevicePwLogStatus: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_DevicePwLogTimestamp: The operator to apply to the field DevicePwLogTimestamp. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. DevicePwLogTimestamp: The date and time this record was collected or calculated. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_DevicePwLogTimestamp: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_DevicePwLogTimestamp: If op_DevicePwLogTimestamp is specified, the field named in this input will be compared to the value in DevicePwLogTimestamp using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_DevicePwLogTimestamp must be specified if op_DevicePwLogTimestamp is specified.
             :type val_f_DevicePwLogTimestamp: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_DevicePwLogTimestamp: If op_DevicePwLogTimestamp is specified, this value will be compared to the value in DevicePwLogTimestamp using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_DevicePwLogTimestamp must be specified if op_DevicePwLogTimestamp is specified.
             :type val_c_DevicePwLogTimestamp: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_DevicePwLogUsernameSecure: The operator to apply to the field DevicePwLogUsernameSecure. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. DevicePwLogUsernameSecure: The username of the device password log. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_DevicePwLogUsernameSecure: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_DevicePwLogUsernameSecure: If op_DevicePwLogUsernameSecure is specified, the field named in this input will be compared to the value in DevicePwLogUsernameSecure using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_DevicePwLogUsernameSecure must be specified if op_DevicePwLogUsernameSecure is specified.
             :type val_f_DevicePwLogUsernameSecure: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_DevicePwLogUsernameSecure: If op_DevicePwLogUsernameSecure is specified, this value will be compared to the value in DevicePwLogUsernameSecure using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_DevicePwLogUsernameSecure must be specified if op_DevicePwLogUsernameSecure is specified.
             :type val_c_DevicePwLogUsernameSecure: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_SecureVersion: The operator to apply to the field SecureVersion. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. SecureVersion: The encryption version of the username and passwords. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_SecureVersion: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_SecureVersion: If op_SecureVersion is specified, the field named in this input will be compared to the value in SecureVersion using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_SecureVersion must be specified if op_SecureVersion is specified.
             :type val_f_SecureVersion: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_SecureVersion: If op_SecureVersion is specified, this value will be compared to the value in SecureVersion using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_SecureVersion must be specified if op_SecureVersion is specified.
             :type val_c_SecureVersion: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param DeviceGroupID: The internal NetMRI identifier of the device groups to which to limit the results.
             :type DeviceGroupID: Array of Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param timestamp: The data returned will represent the device password logs as of this date and time. If omitted, the result will indicate the most recently collected data.
             :type timestamp: DateTime

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param methods: A list of device password log methods. The listed methods will be called on each device password log returned and included in the output. Available methods are: device.
             :type methods: Array of String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param include: A list of associated object types to include in the output. The listed associations will be returned as outputs named according to the association name (see outputs below). Available includes are: device.
             :type include: Array of String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` 0

             :param start: The record number to return in the selected page of data. It will always appear, although it may not be the first record. See the :limit for more information.
             :type start: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` 1000

             :param limit: The size of the page of data, that is, the maximum number of records returned. The limit size will be used to break the data up into pages and the first page with the start record will be returned. So if you have 100 records and use a :limit of 10 and a :start of 10, you will get records 10-19. The maximum limit is 10000.
             :type limit: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` DevicePwLogID

             :param sort: The data field(s) to use for sorting the output. Default is DevicePwLogID. Valid values are DevicePwLogID, DataSourceID, DeviceID, DevicePwLogTimestamp, DevicePwLogProtocol, DevicePwLogSNMPAuthProto, DevicePwLogSNMPPrivProto, DevicePwLogStatus, DevicePwLogUsernameSecure, DevicePwLogPasswordSecure, DevicePwLogEnablePasswordSecure, DevicePwLogSNMPAuthPWSecure, DevicePwLogSNMPPrivPWSecure, SecureVersion.
             :type sort: Array of String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` asc

             :param dir: The direction(s) in which to sort the data. Default is 'asc'. Valid values are 'asc' and 'desc'.
             :type dir: Array of String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param select: The list of attributes to return for each DevicePasswordLog. Valid values are DevicePwLogID, DataSourceID, DeviceID, DevicePwLogTimestamp, DevicePwLogProtocol, DevicePwLogSNMPAuthProto, DevicePwLogSNMPPrivProto, DevicePwLogStatus, DevicePwLogUsernameSecure, DevicePwLogPasswordSecure, DevicePwLogEnablePasswordSecure, DevicePwLogSNMPAuthPWSecure, DevicePwLogSNMPPrivPWSecure, SecureVersion. If empty or omitted, all attributes will be returned.
             :type select: Array

            |  ``api version min:`` 2.8
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param goto_field: The field name for NIOS GOTO that is used for locating a row position of records.
             :type goto_field: String

            |  ``api version min:`` 2.8
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param goto_value: The value of goto_field for NIOS GOTO that is used for locating a row position of records.
             :type goto_value: String

            |  ``api version min:`` 2.3
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param xml_filter: A SetFilter XML structure to further refine the search. The SetFilter will be applied AFTER any search query or field values, but before any limit options. The limit and pagination will be enforced after the filter. Remind that this kind of filter may be costly and inefficient if not associated with a database filtering.
             :type xml_filter: String

            **Outputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :return device_password_logs: An array of the DevicePasswordLog objects that match the specified input criteria.
             :rtype device_password_logs: Array of DevicePasswordLog

            """

        return self.api_list_request(self._get_method_fullname("find"), kwargs)

    def data_source(self, **kwargs):
        """The collector NetMRI that collected this data record.

            **Inputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` True
            |  ``default:`` None

             :param DevicePwLogID: The internal NetMRI identifier for the device password log.
             :type DevicePwLogID: Integer

            **Outputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :return : The collector NetMRI that collected this data record.
             :rtype : DataSource

            """

        return self.api_request(self._get_method_fullname("data_source"), kwargs)

    def device(self, **kwargs):
        """The device from which this data was collected.

            **Inputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` True
            |  ``default:`` None

             :param DevicePwLogID: The internal NetMRI identifier for the device password log.
             :type DevicePwLogID: Integer

            **Outputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :return : The device from which this data was collected.
             :rtype : Device

            """

        return self.api_request(self._get_method_fullname("device"), kwargs)

    def infradevice(self, **kwargs):
        """The device from which this data was collected.

            **Inputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` True
            |  ``default:`` None

             :param DevicePwLogID: The internal NetMRI identifier for the device password log.
             :type DevicePwLogID: Integer

            **Outputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :return : The device from which this data was collected.
             :rtype : InfraDevice

            """

        return self.api_request(self._get_method_fullname("infradevice"), kwargs)



from ..remote import RemoteModel
from infoblox_netmri.utils.utils import check_api_availability


class VlanMemberRemote(RemoteModel):
    """
    Device memberships in VLANs, along with their STP configurations.  This includes switch members (BridgeMemberInd = 1) and devices attached to access ports (BridgeMemberInd = 0).


    |  ``BaseBridgeAddress:`` The spanning tree protocol base bridge address of this bridge. Empty for non-bridge members.
    |  ``attribute type:`` string

    |  ``BaseNumPorts:`` The number of ports on this bridge. Empty for non-bridge members.
    |  ``attribute type:`` number

    |  ``BridgeMemberInd:`` A flag indicating that this VLAN membership record represents a bridge device's configuration entry for the VLAN; that is, that this membership record is for a bridge participating in the VLAN, as opposed to a device attached to an access port.
    |  ``attribute type:`` bool

    |  ``DataSourceID:`` The internal NetMRI identifier for the collector NetMRI that collected this data record.
    |  ``attribute type:`` number

    |  ``DeviceID:`` The internal NetMRI identifier for the device associated with this VLAN membership.
    |  ``attribute type:`` number

    |  ``InterfaceID:`` The internal NetMRI identifier for the switched virtual interface for this VLAN on this device.
    |  ``attribute type:`` number

    |  ``RootBridgeAddress:`` The spanning tree protocol root bridge address; this is the designated root with the STP priority portion removed. Empty for non-bridge members.
    |  ``attribute type:`` string

    |  ``StpBridgeForwardDelay:`` The value that all bridges use for ForwardDelay when this bridge is acting as the root. Empty for non-bridge members.
    |  ``attribute type:`` number

    |  ``StpBridgeHelloTime:`` The value that all bridges use for HelloTime when this bridge is acting as the root. Empty for non-bridge members.
    |  ``attribute type:`` number

    |  ``StpBridgeMaxAge:`` The value that all bridges use for MaxAge when this bridge is acting as the root. Empty for non-bridge members.
    |  ``attribute type:`` number

    |  ``StpDesignatedRoot:`` The bridge identifier for this bridge. Empty for non-bridge members.
    |  ``attribute type:`` string

    |  ``StpForwardDelay:`` This time value, measured in units of hundredths of a second, controls how fast a port changes its spanning state when moving towards the Forwarding state. The value determines how long the port stays in each of the Listening and Learning states, which precede the Forwarding state. This value is also used when a topology change has been detected and is underway, to age all dynamic entries in the Forwarding Database. This is the value currently in use on this bridge. Empty for non-bridge members.
    |  ``attribute type:`` number

    |  ``StpHelloTime:`` The amount of time between the transmission of Configuration bridge PDUs by this node on any port when it is the root of the spanning tree, or trying to become so, in units of hundredths of a second. This is the actual value that this bridge is currently using.
    |  ``attribute type:`` number

    |  ``StpHoldTime:`` This time value determines the interval length during which no more than two Configuration bridge PDUs shall be transmitted by this node, in units of hundredths of a second.
    |  ``attribute type:`` number

    |  ``StpMaxAge:`` The maximum age of Spanning Tree Protocol information learned from the network on any port before it is discarded, in units of hundredths of a second. This is the actual value that this bridge is currently using. Empty for non-bridge members.
    |  ``attribute type:`` number

    |  ``StpPriority:`` The spanning tree protocol priority for this bridge in this VLAN. Empty for non-bridge members.
    |  ``attribute type:`` number

    |  ``StpProtocolSpecification:`` The protocol of spanning tree running for this VLAN. Empty for non-bridge members.
    |  ``attribute type:`` string

    |  ``StpRootCost:`` The cost of the path to the root bridge as seen from this bridge. Empty for non-bridge members.
    |  ``attribute type:`` number

    |  ``StpRootPort:`` The port number (i.e., the SwitchPortNumber attribute value of the interface) of the port that offers the lowest cost path from this bridge to the root bridge.
    |  ``attribute type:`` number

    |  ``StpTopChanges:`` The total number of topology changes detected by this bridge since the last reset. Empty for non-bridge members.
    |  ``attribute type:`` number

    |  ``VlanID:`` The internal NetMRI identifier of the VLAN associated with this VLAN membership.
    |  ``attribute type:`` number

    |  ``VlanMemberChangedCols:`` The fields that changed between this revision of the record and the previous revision.
    |  ``attribute type:`` string

    |  ``VlanMemberEndTime:`` The ending effective time of this revision of this record, or empty if still in effect.
    |  ``attribute type:`` datetime

    |  ``VlanMemberID:`` The internal NetMRI identifier for this VLAN membership.
    |  ``attribute type:`` number

    |  ``VlanMemberStartTime:`` The starting effective time of this revision of the record.
    |  ``attribute type:`` datetime

    |  ``VlanMemberTimestamp:`` The date and time this record was collected or calculated.
    |  ``attribute type:`` datetime

    |  ``VlanName:`` The name of this VLAN as configured on this device. Empty for non-bridge members.
    |  ``attribute type:`` string

    |  ``VlanState:`` The state of this VLAN on this device. Empty for non-bridge members.

The state 'mtuTooBigForDevice' indicates that this device cannot participate in this VLAN because the VLAN's MTU is larger than the device can support.

The state 'mtuTooBigForTrunk' indicates that while this VLAN's MTU is supported by this device, it is too large for one or more of the device's trunk ports.
    |  ``attribute type:`` string

    |  ``VlanType:`` The type of this VLAN (1:ethernet, 2:fddi, 3:tokenRing, 4:fddiNet, 5:trNet, 6:deprecated) as configured on this device. Empty for non-bridge members.
    |  ``attribute type:`` string





    |  ``VTPDomain:`` Management domain name if VLAN is VTP managed.
    |  ``attribute type:`` string


    |  ``network_id:`` The Network View ID assigned to the Vlan membership.
    |  ``attribute type:`` number

    """

    properties = ("BaseBridgeAddress",
                  "BaseNumPorts",
                  "BridgeMemberInd",
                  "DataSourceID",
                  "DeviceID",
                  "InterfaceID",
                  "RootBridgeAddress",
                  "StpBridgeForwardDelay",
                  "StpBridgeHelloTime",
                  "StpBridgeMaxAge",
                  "StpDesignatedRoot",
                  "StpForwardDelay",
                  "StpHelloTime",
                  "StpHoldTime",
                  "StpMaxAge",
                  "StpPriority",
                  "StpProtocolSpecification",
                  "StpRootCost",
                  "StpRootPort",
                  "StpTopChanges",
                  "VlanID",
                  "VlanMemberChangedCols",
                  "VlanMemberEndTime",
                  "VlanMemberID",
                  "VlanMemberStartTime",
                  "VlanMemberTimestamp",
                  "VlanName",
                  "VlanState",
                  "VlanType",
                  "VTPDomain",
                  "network_id",
                  )

    @property
    @check_api_availability
    def data_source(self):
        """
        The NetMRI device that collected this record.
        ``attribute type:`` model
        """
        return self.broker.data_source(**{"VlanMemberID": self.VlanMemberID})

    @property
    @check_api_availability
    def device(self):
        """
        The device associated with this VLAN membership.
        ``attribute type:`` model
        """
        return self.broker.device(**{"VlanMemberID": self.VlanMemberID})

    @property
    @check_api_availability
    def interface(self):
        """
        The switched virtual interface for this VLAN on this device.
        ``attribute type:`` model
        """
        return self.broker.interface(**{"VlanMemberID": self.VlanMemberID})

    @property
    @check_api_availability
    def vlan(self):
        """
        The VLAN associated with this VLAN membership.
        ``attribute type:`` model
        """
        return self.broker.vlan(**{"VlanMemberID": self.VlanMemberID})

    @property
    @check_api_availability
    def infradevice(self):
        """
        The device associated with this VLAN membership.
        ``attribute type:`` model
        """
        return self.broker.infradevice(**{"VlanMemberID": self.VlanMemberID})



from ..remote import RemoteModel


class NetworkViewViwerAssociatedVrfsGridRemote(RemoteModel):
    """



    |  ``id:`` none
    |  ``attribute type:`` string

    |  ``DeviceName:`` none
    |  ``attribute type:`` string

    |  ``VirtualNetworkMemberName:`` none
    |  ``attribute type:`` string

    |  ``RouteDistinguisher:`` none
    |  ``attribute type:`` string

    """

    properties = ("id",
                  "DeviceName",
                  "VirtualNetworkMemberName",
                  "RouteDistinguisher",
                  )



from ..remote import RemoteModel


class ReportManagerInactiveReportsGridRemote(RemoteModel):
    """



    |  ``id:`` none
    |  ``attribute type:`` string

    |  ``report_run_id:`` none
    |  ``attribute type:`` string

    |  ``report_name:`` none
    |  ``attribute type:`` string

    |  ``report_type:`` none
    |  ``attribute type:`` string

    |  ``created_by:`` none
    |  ``attribute type:`` string

    |  ``column_to_sort_by:`` none
    |  ``attribute type:`` string

    |  ``status:`` none
    |  ``attribute type:`` string

    |  ``report_run_identifier:`` none
    |  ``attribute type:`` string

    |  ``report_file:`` none
    |  ``attribute type:`` string

    |  ``size:`` none
    |  ``attribute type:`` string

    |  ``report_id:`` none
    |  ``attribute type:`` string

    |  ``report_identifier:`` none
    |  ``attribute type:`` string

    |  ``content_type:`` none
    |  ``attribute type:`` string

    |  ``last_action_timestamp:`` none
    |  ``attribute type:`` string

    """

    properties = ("id",
                  "report_run_id",
                  "report_name",
                  "report_type",
                  "created_by",
                  "column_to_sort_by",
                  "status",
                  "report_run_identifier",
                  "report_file",
                  "size",
                  "report_id",
                  "report_identifier",
                  "content_type",
                  "last_action_timestamp",
                  )



from ..remote import RemoteModel
from infoblox_netmri.utils.utils import check_api_availability


class EndHostMacAddressRemote(RemoteModel):
    """
    MAC Addresses of end hosts on the network.


    |  ``EndHostMACAddressID:`` The internal NetMRI identifier for the End Host MAC Address entry.
    |  ``attribute type:`` number

    |  ``NetworkID:`` The internal NetMRI identifier of the associated network.
    |  ``attribute type:`` number

    |  ``MACAddress:`` The MAC address of the end host.
    |  ``attribute type:`` string

    |  ``IPAddress:`` The IP address of the end host.
    |  ``attribute type:`` string

    |  ``IPAddressNumeric:`` The IP address of the end host, in numerical form.
    |  ``attribute type:`` number

    |  ``DataSourceID:`` The internal NetMRI identifier for the collector NetMRI that collected this data record.
    |  ``attribute type:`` number


    |  ``DeviceType:`` The determined type of the end host.
    |  ``attribute type:`` string

    |  ``DeviceName:`` The determined name of the end host.
    |  ``attribute type:`` string

    |  ``DeviceNetBIOSName:`` The NetBIOS name of the end host.
    |  ``attribute type:`` string

    |  ``DeviceID:`` The internal NetMRI identifier for the associated Device record.
    |  ``attribute type:`` number

    |  ``ifIndex:`` The interface index on which the end host was found.
    |  ``attribute type:`` number

    |  ``InterfaceID:`` The internal NetMRI identifier for the interface on which the end host was found.
    |  ``attribute type:`` number

    |  ``InfraDeviceID:`` The internal NetMRI identifier for the InfraDevice on which the end host was found.
    |  ``attribute type:`` number

    |  ``NeighborID:`` The internal NetMRI identifier for the associated Neighbor record.
    |  ``attribute type:`` number

    |  ``EndHostMACAddressTimestamp:`` The date and time this record was collected or calculated.
    |  ``attribute type:`` datetime

    |  ``FirstSeenTime:`` The date and time this record was first seen.
    |  ``attribute type:`` datetime

    |  ``EndHostMACAddressStartTime:`` The starting effective time of this record.
    |  ``attribute type:`` datetime

    |  ``EndHostMACAddressEndTime:`` The ending effective time of this record, or empty if still in effect.
    |  ``attribute type:`` datetime

    |  ``EndHostMACAddressChangedCols:`` The fields that changed between this revision of the record and the previous revision.
    |  ``attribute type:`` string

    |  ``Network:`` The name of the Network View associated.
    |  ``attribute type:`` string

    """

    properties = ("EndHostMACAddressID",
                  "NetworkID",
                  "MACAddress",
                  "IPAddress",
                  "IPAddressNumeric",
                  "DataSourceID",
                  "DeviceType",
                  "DeviceName",
                  "DeviceNetBIOSName",
                  "DeviceID",
                  "ifIndex",
                  "InterfaceID",
                  "InfraDeviceID",
                  "NeighborID",
                  "EndHostMACAddressTimestamp",
                  "FirstSeenTime",
                  "EndHostMACAddressStartTime",
                  "EndHostMACAddressEndTime",
                  "EndHostMACAddressChangedCols",
                  "Network",
                  )

    @property
    @check_api_availability
    def data_source(self):
        """
        The collector NetMRI that collected this data record.
        ``attribute type:`` model
        """
        return self.broker.data_source(**{"EndHostMACAddressID": self.EndHostMACAddressID})



from ..broker import Broker


class JobProcessBroker(Broker):
    controller = "job_processes"

    def index(self, **kwargs):
        """Lists the available job processes. Any of the inputs listed may be be used to narrow the list; other inputs will be ignored. Of the various ways to query lists, using this method is most efficient.

            **Inputs**

            |  ``api version min:`` 2.6
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param id: The internal identifier of this process.
             :type id: Array of Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param methods: A list of job process methods. The listed methods will be called on each job process returned and included in the output. Available methods are: device.
             :type methods: Array of String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param include: A list of associated object types to include in the output. The listed associations will be returned as outputs named according to the association name (see outputs below). Available includes are: device.
             :type include: Array of String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` 0

             :param start: The record number to return in the selected page of data. It will always appear, although it may not be the first record. See the :limit for more information.
             :type start: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` 1000

             :param limit: The size of the page of data, that is, the maximum number of records returned. The limit size will be used to break the data up into pages and the first page with the start record will be returned. So if you have 100 records and use a :limit of 10 and a :start of 10, you will get records 10-19. The maximum limit is 10000.
             :type limit: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` id

             :param sort: The data field(s) to use for sorting the output. Default is id. Valid values are id, process_type, user_name, job_handler_id, job_id, input_data, status, last_status_at, started_at, completed_at, created_at, updated_at, revert_ind, deploy_ind, device_id.
             :type sort: Array of String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` asc

             :param dir: The direction(s) in which to sort the data. Default is 'asc'. Valid values are 'asc' and 'desc'.
             :type dir: Array of String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param select: The list of attributes to return for each JobProcess. Valid values are id, process_type, user_name, job_handler_id, job_id, input_data, status, last_status_at, started_at, completed_at, created_at, updated_at, revert_ind, deploy_ind, device_id. If empty or omitted, all attributes will be returned.
             :type select: Array

            |  ``api version min:`` 2.8
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param goto_field: The field name for NIOS GOTO that is used for locating a row position of records.
             :type goto_field: String

            |  ``api version min:`` 2.8
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param goto_value: The value of goto_field for NIOS GOTO that is used for locating a row position of records.
             :type goto_value: String

            **Outputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :return job_processes: An array of the JobProcess objects that match the specified input criteria.
             :rtype job_processes: Array of JobProcess

            """

        return self.api_list_request(self._get_method_fullname("index"), kwargs)

    def show(self, **kwargs):
        """Shows the details for the specified job process.

            **Inputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` True
            |  ``default:`` None

             :param id: The internal identifier of this process.
             :type id: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param methods: A list of job process methods. The listed methods will be called on each job process returned and included in the output. Available methods are: device.
             :type methods: Array of String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param include: A list of associated object types to include in the output. The listed associations will be returned as outputs named according to the association name (see outputs below). Available includes are: device.
             :type include: Array of String

            **Outputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :return job_process: The job process identified by the specified id.
             :rtype job_process: JobProcess

            """

        return self.api_request(self._get_method_fullname("show"), kwargs)

    def search(self, **kwargs):
        """Lists the available job processes matching the input criteria. This method provides a more flexible search interface than the index method, but searching using this method is more demanding on the system and will not perform to the same level as the index method. The input fields listed below will be used as in the index method, to filter the result, along with the optional query string and XML filter described below.

            **Inputs**

            |  ``api version min:`` 2.6
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param completed_at: The date and time the execution of this process was completed.
             :type completed_at: Array of DateTime

            |  ``api version min:`` 2.6
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param created_at: The date and time the record was initially created in NetMRI.
             :type created_at: Array of DateTime

            |  ``api version min:`` 2.6
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param deploy_ind: Indication that this process must be re-executed for post-deploy operation when completed with success.
             :type deploy_ind: Array of Boolean

            |  ``api version min:`` 2.6
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param device_id: The internal identifier of the device that this process is running against.
             :type device_id: Array of Integer

            |  ``api version min:`` 2.6
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param id: The internal identifier of this process.
             :type id: Array of Integer

            |  ``api version min:`` 2.6
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param input_data: Data parameters for the execution.
             :type input_data: Array of String

            |  ``api version min:`` 2.6
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param job_handler_id: The internal identifier of the Runner that handled the execution of this process.
             :type job_handler_id: Array of Integer

            |  ``api version min:`` 2.6
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param job_id: The internal identifier of job that process belongs to.
             :type job_id: Array of Integer

            |  ``api version min:`` 2.6
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param last_status_at: The date and time the status was updated.
             :type last_status_at: Array of DateTime

            |  ``api version min:`` 2.6
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param process_type: The kind of process_type.
             :type process_type: Array of String

            |  ``api version min:`` 2.6
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param revert_ind: Indication that this process must be re-executed for reversion if it is completed with an error.
             :type revert_ind: Array of Boolean

            |  ``api version min:`` 2.6
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param started_at: The date and time the execution of this process was started.
             :type started_at: Array of DateTime

            |  ``api version min:`` 2.6
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param status: The last known execution status for this target.
             :type status: Array of String

            |  ``api version min:`` 2.6
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param updated_at: The date and time the record was last modified in NetMRI.
             :type updated_at: Array of DateTime

            |  ``api version min:`` 2.6
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param user_name: The name of the user that ran this execution.
             :type user_name: Array of String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param methods: A list of job process methods. The listed methods will be called on each job process returned and included in the output. Available methods are: device.
             :type methods: Array of String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param include: A list of associated object types to include in the output. The listed associations will be returned as outputs named according to the association name (see outputs below). Available includes are: device.
             :type include: Array of String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` 0

             :param start: The record number to return in the selected page of data. It will always appear, although it may not be the first record. See the :limit for more information.
             :type start: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` 1000

             :param limit: The size of the page of data, that is, the maximum number of records returned. The limit size will be used to break the data up into pages and the first page with the start record will be returned. So if you have 100 records and use a :limit of 10 and a :start of 10, you will get records 10-19. The maximum limit is 10000.
             :type limit: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` id

             :param sort: The data field(s) to use for sorting the output. Default is id. Valid values are id, process_type, user_name, job_handler_id, job_id, input_data, status, last_status_at, started_at, completed_at, created_at, updated_at, revert_ind, deploy_ind, device_id.
             :type sort: Array of String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` asc

             :param dir: The direction(s) in which to sort the data. Default is 'asc'. Valid values are 'asc' and 'desc'.
             :type dir: Array of String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param select: The list of attributes to return for each JobProcess. Valid values are id, process_type, user_name, job_handler_id, job_id, input_data, status, last_status_at, started_at, completed_at, created_at, updated_at, revert_ind, deploy_ind, device_id. If empty or omitted, all attributes will be returned.
             :type select: Array

            |  ``api version min:`` 2.8
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param goto_field: The field name for NIOS GOTO that is used for locating a row position of records.
             :type goto_field: String

            |  ``api version min:`` 2.8
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param goto_value: The value of goto_field for NIOS GOTO that is used for locating a row position of records.
             :type goto_value: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param query: This value will be matched against job processes, looking to see if one or more of the listed attributes contain the passed value. You may also surround the value with '/' and '/' to perform a regular expression search rather than a containment operation. Any record that matches will be returned. The attributes searched are: completed_at, created_at, deploy_ind, device_id, id, input_data, job_handler_id, job_id, last_status_at, process_type, revert_ind, started_at, status, updated_at, user_name.
             :type query: String

            |  ``api version min:`` 2.3
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param xml_filter: A SetFilter XML structure to further refine the search. The SetFilter will be applied AFTER any search query or field values, but before any limit options. The limit and pagination will be enforced after the filter. Remind that this kind of filter may be costly and inefficient if not associated with a database filtering.
             :type xml_filter: String

            **Outputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :return job_processes: An array of the JobProcess objects that match the specified input criteria.
             :rtype job_processes: Array of JobProcess

            """

        return self.api_list_request(self._get_method_fullname("search"), kwargs)

    def find(self, **kwargs):
        """Lists the available job processes matching the input specification. This provides the most flexible search specification of all the query mechanisms, enabling searching using comparison operations other than equality. However, it is more complex to use and will not perform as efficiently as the index or search methods. In the input descriptions below, 'field names' refers to the following fields: completed_at, created_at, deploy_ind, device_id, id, input_data, job_handler_id, job_id, last_status_at, process_type, revert_ind, started_at, status, updated_at, user_name.

            **Inputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_completed_at: The operator to apply to the field completed_at. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. completed_at: The date and time the execution of this process was completed. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_completed_at: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_completed_at: If op_completed_at is specified, the field named in this input will be compared to the value in completed_at using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_completed_at must be specified if op_completed_at is specified.
             :type val_f_completed_at: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_completed_at: If op_completed_at is specified, this value will be compared to the value in completed_at using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_completed_at must be specified if op_completed_at is specified.
             :type val_c_completed_at: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_created_at: The operator to apply to the field created_at. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. created_at: The date and time the record was initially created in NetMRI. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_created_at: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_created_at: If op_created_at is specified, the field named in this input will be compared to the value in created_at using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_created_at must be specified if op_created_at is specified.
             :type val_f_created_at: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_created_at: If op_created_at is specified, this value will be compared to the value in created_at using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_created_at must be specified if op_created_at is specified.
             :type val_c_created_at: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_deploy_ind: The operator to apply to the field deploy_ind. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. deploy_ind: Indication that this process must be re-executed for post-deploy operation when completed with success. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_deploy_ind: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_deploy_ind: If op_deploy_ind is specified, the field named in this input will be compared to the value in deploy_ind using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_deploy_ind must be specified if op_deploy_ind is specified.
             :type val_f_deploy_ind: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_deploy_ind: If op_deploy_ind is specified, this value will be compared to the value in deploy_ind using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_deploy_ind must be specified if op_deploy_ind is specified.
             :type val_c_deploy_ind: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_device_id: The operator to apply to the field device_id. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. device_id: The internal identifier of the device that this process is running against. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_device_id: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_device_id: If op_device_id is specified, the field named in this input will be compared to the value in device_id using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_device_id must be specified if op_device_id is specified.
             :type val_f_device_id: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_device_id: If op_device_id is specified, this value will be compared to the value in device_id using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_device_id must be specified if op_device_id is specified.
             :type val_c_device_id: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_id: The operator to apply to the field id. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. id: The internal identifier of this process. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_id: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_id: If op_id is specified, the field named in this input will be compared to the value in id using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_id must be specified if op_id is specified.
             :type val_f_id: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_id: If op_id is specified, this value will be compared to the value in id using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_id must be specified if op_id is specified.
             :type val_c_id: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_input_data: The operator to apply to the field input_data. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. input_data: Data parameters for the execution. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_input_data: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_input_data: If op_input_data is specified, the field named in this input will be compared to the value in input_data using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_input_data must be specified if op_input_data is specified.
             :type val_f_input_data: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_input_data: If op_input_data is specified, this value will be compared to the value in input_data using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_input_data must be specified if op_input_data is specified.
             :type val_c_input_data: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_job_handler_id: The operator to apply to the field job_handler_id. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. job_handler_id: The internal identifier of the Runner that handled the execution of this process. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_job_handler_id: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_job_handler_id: If op_job_handler_id is specified, the field named in this input will be compared to the value in job_handler_id using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_job_handler_id must be specified if op_job_handler_id is specified.
             :type val_f_job_handler_id: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_job_handler_id: If op_job_handler_id is specified, this value will be compared to the value in job_handler_id using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_job_handler_id must be specified if op_job_handler_id is specified.
             :type val_c_job_handler_id: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_job_id: The operator to apply to the field job_id. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. job_id: The internal identifier of job that process belongs to. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_job_id: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_job_id: If op_job_id is specified, the field named in this input will be compared to the value in job_id using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_job_id must be specified if op_job_id is specified.
             :type val_f_job_id: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_job_id: If op_job_id is specified, this value will be compared to the value in job_id using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_job_id must be specified if op_job_id is specified.
             :type val_c_job_id: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_last_status_at: The operator to apply to the field last_status_at. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. last_status_at: The date and time the status was updated. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_last_status_at: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_last_status_at: If op_last_status_at is specified, the field named in this input will be compared to the value in last_status_at using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_last_status_at must be specified if op_last_status_at is specified.
             :type val_f_last_status_at: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_last_status_at: If op_last_status_at is specified, this value will be compared to the value in last_status_at using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_last_status_at must be specified if op_last_status_at is specified.
             :type val_c_last_status_at: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_process_type: The operator to apply to the field process_type. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. process_type: The kind of process_type. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_process_type: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_process_type: If op_process_type is specified, the field named in this input will be compared to the value in process_type using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_process_type must be specified if op_process_type is specified.
             :type val_f_process_type: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_process_type: If op_process_type is specified, this value will be compared to the value in process_type using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_process_type must be specified if op_process_type is specified.
             :type val_c_process_type: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_revert_ind: The operator to apply to the field revert_ind. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. revert_ind: Indication that this process must be re-executed for reversion if it is completed with an error. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_revert_ind: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_revert_ind: If op_revert_ind is specified, the field named in this input will be compared to the value in revert_ind using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_revert_ind must be specified if op_revert_ind is specified.
             :type val_f_revert_ind: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_revert_ind: If op_revert_ind is specified, this value will be compared to the value in revert_ind using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_revert_ind must be specified if op_revert_ind is specified.
             :type val_c_revert_ind: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_started_at: The operator to apply to the field started_at. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. started_at: The date and time the execution of this process was started. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_started_at: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_started_at: If op_started_at is specified, the field named in this input will be compared to the value in started_at using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_started_at must be specified if op_started_at is specified.
             :type val_f_started_at: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_started_at: If op_started_at is specified, this value will be compared to the value in started_at using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_started_at must be specified if op_started_at is specified.
             :type val_c_started_at: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_status: The operator to apply to the field status. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. status: The last known execution status for this target. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_status: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_status: If op_status is specified, the field named in this input will be compared to the value in status using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_status must be specified if op_status is specified.
             :type val_f_status: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_status: If op_status is specified, this value will be compared to the value in status using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_status must be specified if op_status is specified.
             :type val_c_status: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_updated_at: The operator to apply to the field updated_at. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. updated_at: The date and time the record was last modified in NetMRI. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_updated_at: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_updated_at: If op_updated_at is specified, the field named in this input will be compared to the value in updated_at using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_updated_at must be specified if op_updated_at is specified.
             :type val_f_updated_at: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_updated_at: If op_updated_at is specified, this value will be compared to the value in updated_at using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_updated_at must be specified if op_updated_at is specified.
             :type val_c_updated_at: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_user_name: The operator to apply to the field user_name. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. user_name: The name of the user that ran this execution. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_user_name: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_user_name: If op_user_name is specified, the field named in this input will be compared to the value in user_name using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_user_name must be specified if op_user_name is specified.
             :type val_f_user_name: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_user_name: If op_user_name is specified, this value will be compared to the value in user_name using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_user_name must be specified if op_user_name is specified.
             :type val_c_user_name: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param methods: A list of job process methods. The listed methods will be called on each job process returned and included in the output. Available methods are: device.
             :type methods: Array of String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param include: A list of associated object types to include in the output. The listed associations will be returned as outputs named according to the association name (see outputs below). Available includes are: device.
             :type include: Array of String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` 0

             :param start: The record number to return in the selected page of data. It will always appear, although it may not be the first record. See the :limit for more information.
             :type start: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` 1000

             :param limit: The size of the page of data, that is, the maximum number of records returned. The limit size will be used to break the data up into pages and the first page with the start record will be returned. So if you have 100 records and use a :limit of 10 and a :start of 10, you will get records 10-19. The maximum limit is 10000.
             :type limit: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` id

             :param sort: The data field(s) to use for sorting the output. Default is id. Valid values are id, process_type, user_name, job_handler_id, job_id, input_data, status, last_status_at, started_at, completed_at, created_at, updated_at, revert_ind, deploy_ind, device_id.
             :type sort: Array of String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` asc

             :param dir: The direction(s) in which to sort the data. Default is 'asc'. Valid values are 'asc' and 'desc'.
             :type dir: Array of String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param select: The list of attributes to return for each JobProcess. Valid values are id, process_type, user_name, job_handler_id, job_id, input_data, status, last_status_at, started_at, completed_at, created_at, updated_at, revert_ind, deploy_ind, device_id. If empty or omitted, all attributes will be returned.
             :type select: Array

            |  ``api version min:`` 2.8
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param goto_field: The field name for NIOS GOTO that is used for locating a row position of records.
             :type goto_field: String

            |  ``api version min:`` 2.8
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param goto_value: The value of goto_field for NIOS GOTO that is used for locating a row position of records.
             :type goto_value: String

            |  ``api version min:`` 2.3
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param xml_filter: A SetFilter XML structure to further refine the search. The SetFilter will be applied AFTER any search query or field values, but before any limit options. The limit and pagination will be enforced after the filter. Remind that this kind of filter may be costly and inefficient if not associated with a database filtering.
             :type xml_filter: String

            **Outputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :return job_processes: An array of the JobProcess objects that match the specified input criteria.
             :rtype job_processes: Array of JobProcess

            """

        return self.api_list_request(self._get_method_fullname("find"), kwargs)

    def device(self, **kwargs):
        """The device against which this Process will be executed.

            **Inputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` True
            |  ``default:`` None

             :param id: The internal identifier of this process.
             :type id: Integer

            **Outputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :return : The device against which this Process will be executed.
             :rtype : Device

            """

        return self.api_request(self._get_method_fullname("device"), kwargs)

    def stream_output(self, **kwargs):
        """Return log output stream.

            **Inputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param job_id: The job id to list files for. Required unless job_process_id is specified.
             :type job_id: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param job_process_id: The job process id to list files for. Required unless job_id and device_id are specified.
             :type job_process_id: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param device_id: The Device ID to list files for. Required unless job_process_id is specified.
             :type device_id: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` script-allout

             :param stream: Name of expected stream.
             :type stream: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` 0

             :param first: First line expected.
             :type first: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` -1

             :param end_line: Number of the end line to read, if -1, read all available.
             :type end_line: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` -1

             :param count: Number of lines to read, if -1, read all available.
             :type count: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` 0

             :param retry_limit: Number of seconds before stopping retry efforts, if 0 do not retry.
             :type retry_limit: Integer

            **Outputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :return stream: The log output stream.
             :rtype stream: Array of String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :return status: The status of the job process.
             :rtype status: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :return completed_at: The date and time when the job process was completed. returned nil if it is not completed
             :rtype completed_at: DateTime

            """

        return self.api_request(self._get_method_fullname("stream_output"), kwargs)

    def execution_log_files(self, **kwargs):
        """Downloads the per-device files for a job.

            **Inputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param job_id: The job id to list files for. Required unless job_process_id is specified.
             :type job_id: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param device_id: The Device ID to list files for. Required unless job_process_id is specified.
             :type device_id: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param job_process_id: The job process id to list files for. Required unless job_id and deviceid are specified.
             :type job_process_id: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param filename: An optional filename to download. If the special filename "all.zip" is passed, a ZIP file containing all job files will be created
             :type filename: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param read: The number of bytes to read file from.
             :type read: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param start: A position in the file to start transmission from. Available for log files only.
             :type start: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` 0

             :param retry_limit: Number of seconds before stopping retry efforts. Usually used when viewing a log for a new job.
             :type retry_limit: Integer

            **Outputs**

            """

        return self.api_mixed_request(self._get_method_fullname("execution_log_files"), kwargs)

    def show_job_files(self, **kwargs):
        """Show files for a job.

            **Inputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param job_id: The job id to list files for. Required unless job_process_id is specified.
             :type job_id: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param job_process_id: The job process id to list files for. Required unless job_id and device_id are specified.
             :type job_process_id: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param device_id: The Device ID to list files for. Required unless job_process_id is specified.
             :type device_id: Integer

            **Outputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :return filenames: An array of filenames that match the specified input criteria.
             :rtype filenames: Array of String

            """

        return self.api_request(self._get_method_fullname("show_job_files"), kwargs)
